@@ -4,6 +4,7 @@ import string
 import random
 
 from hashlib import md5
+from . import _pyco_json 
 from . import _pyco_json as _json
 from . import (
     _coimp,
@@ -24,7 +25,10 @@ from ._coimp import (
     clean_modules_from_dir,
 )
 
-__version__ = '0.1.8'
+__version__ = '0.1.9'
+
+## fixed: compat with _json.cpython on python>=3.7  
+sys.modules["pyco_utils._json"] = _json
 
 
 def md5sum(content):
