@@ -3,7 +3,6 @@ import logging
 from logging.handlers import RotatingFileHandler
 from pprint import pformat
 from functools import wraps
-from ._format import pf_echo, pf_response
 
 fmt_str = '[%(asctime)s]%(module)s - %(funcName)s - %(message)s'
 fmt = logging.Formatter(fmt_str)
@@ -84,6 +83,7 @@ def log_func(logger_name="LOG", level=logging.INFO, pf=pformat, **options):
     :return: Any Result of Func
     """
     logger = getLogger(logger_name, **options)
+    from pyco_utils._format import pf_echo, pf_response
 
     def deco(func):
         @wraps(func)
